def player_id_query():
  query = """query EventEntrants($eventId: ID!, $page: Int!) {
  event(id: $eventId) {
    entrants(query: {
      page: $page
      perPage: 32
    }) {
      nodes {
        participants {
          gamerTag
          player {
            id
          }
        }
      }
    }
  }
  } """
  
  return query

def event_id_query():
  query = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    events {
      id
      slug
    }
  }
  } """
  
  return query

def metadata_query():
  query = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    id
    venueName
    venueAddress
    name
    url
    links {
      facebook
      discord
    }
    addrState
    startAt
    endAt
    numAttendees
  }
  } """

  return query

def metadata_with_brackets_query():
  query = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    id
    venueName
    venueAddress
    name
    url
    links {
      facebook
      discord
    }
    addrState
    startAt
    endAt
    numAttendees
    events {
      id
      name
      slug
    }
  }
  } """
  
  return query

def events_query():
  query = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    events {
      id
      name
      slug
    }
  }
  } """
  
  return query

def show_sets_query():
  query = """query EventSets($eventId: ID!, $page: Int!) {
  event(id: $eventId) {
    sets(page: $page, perPage: 32) {
      nodes {
        id
        slots {
          standing {
            id
            placement
            stats {
              score {
                value
              }
            }
          }
          entrant {
            id
            name
          }
        }
        phaseGroup {
          id
          phase {
            name
          }
        }
      }
    }
  }
  }"""
  
  return query

def show_players_query():
  query = """query EventStandings($eventId: ID!, $page: Int!) {
  event(id: $eventId) {
    id
    name
    standings(query: {
      perPage: 32,
      page: $page}){
      nodes {
        placement
        entrant {
          id
          name
          participants {
            user {
              name
              location {
                state
                country
              }
              player {
                id
              }
            }
          }
          seeds {
            seedNum
          }
        }
      }
    }
  }
  }"""
  
  return query

def show_events_brackets_query():
  query = """query ($tourneySlug: String!) {
  tournament(slug: $tourneySlug) {
    events {
      name
      slug
      phaseGroups {
        id
      }
    }
  }
  }"""
  
  return query

def show_player_sets_query():
  query = """query EventSets($eventId: ID!, $playerId: ID!, $page: Int!) {
  event(id: $eventId) {
    sets(
      page: $page
      perPage: 16
      filters: {
        playerIds: [$playerId]
      }
    ) {
      nodes {
        id
        fullRoundText
        slots {
          standing {
            placement
            stats {
              score {
                value
              }
            }
          }
          entrant {
            id
            name
            participants {
              user {
                name 
                location {
                  state
                  country
                }
      					player {
                  id
                }
              }
            }
          }
        }
        phaseGroup {
          id
        }
      }
    }
  }
  } """
  
  return query

def show_head_to_head_query():
  query = """query EventSets($eventId: ID!, $playerId: ID!, $page: Int!) {
  event(id: $eventId) {
    sets(
      page: $page
      perPage: 16
      filters: {
        playerIds: [$playerId]
      }
    ) {
      nodes {
        id
        fullRoundText
        slots {
          standing {
            placement
            stats {
              score {
                value
              }
            }
          }
          entrant {
            id
            name
            participants {
              user {
                name 
                location {
                  state
                  country
                }
      					player {
                  id
                }
              }
            }
          }
        }
        phaseGroup {
          id
        }
      }
    }
  }
  } """
  
  return query

def bracket_show_players_query():
  query = """query ($phaseGroupId: ID!, $page: Int!) {
  phaseGroup(id: $phaseGroupId) {
    id
    seeds (query: {page: $page, perPage: 32}) {
      nodes {
        seedNum
        placement
        entrant {
          id
          name
        }
        players {
          id
          user {
            name
            location {
              state
              country
            }
          }
        }
      }
    }
  }
  }"""

  return query

def bracket_show_sets_query():
  query = """query PhaseGroupSets($phaseGroupId: ID!, $page:Int!){
  phaseGroup(id:$phaseGroupId){
    phase {
      name
    }
    sets(
      page: $page
      perPage: 32
    ){
      nodes{
        id
        slots{
          entrant{
            id
            name
          }
          standing {
            placement
            stats {
              score {
                value
              }
            }
          }
        }
      }
    }
  }
  } """
  
  return query


import requests
import json
from pysmashgg import exceptions, tournaments
from time import sleep

class SmashGG(object):
  def __init__(self, key):
    self.key = key
    self.header = {"Authorization": "Bearer " + key}
    
  def set_key_and_header(self, new_key):
    self.key = new_key
    self.header = {"Authorization": "Bearer " + new_key}

  def print_key(self):
    print(self.key)

  def print_header(self):
    print(self.header)

  # Metadata for a tournament
  def tournament_show(self, tournament_name):
    return tournaments.show(tournament_name, self.header)

  # Metadata for a tournament with a bracket
  def tournament_show_with_brackets(self, tournament_name, event_name):
    return tournaments.show_with_brackets(tournament_name, event_name, self.header)

  # List of events for a tournament
  def tournament_show_events(self, tournament_name):
    return tournaments.show_events(tournament_name, self.header)

  # List of sets for an event -- Probably don't mess with sleep time
  def tournament_show_sets(self, tournament_name, event_name, sleep_time=15):
    return tournaments.show_sets(tournament_name, event_name, self.header, sleep_time)

  # List of players for an event -- Probably don't mess with sleep time
  def tournament_show_players(self, tournament_name, event_name, sleep_time=15):
    return tournaments.show_players(tournament_name, event_name, self.header, sleep_time)

  def tournament_show_events_brackets(self, tournament_name, event_name):
    return tournaments.show_events_brackets(tournament_name, event_name, self.header)

  def tournament_show_player_sets(self, tournament_name, event_name, player_name):
    return tournaments.show_player_sets(tournament_name, event_name, player_name, self.header)

  def tournament_show_head_to_head(self, tournament_name, event_name, player1_name, player2_name):
    return tournaments.show_head_to_head(tournament_name, event_name, player1_name, player2_name, self.header)

  def bracket_show_players(self, bracket_id, sleep_time=15):
    return tournaments.bracket_show_players(bracket_id, sleep_time, self.header)

  def bracket_show_sets(self, bracket_id, sleep_time=15):
    return tournaments.bracket_show_sets(bracket_id, sleep_time, self.header)


import requests

class TooManyRequestsError(Exception):
  # Means we're submitting too many requests
  pass

class BadRequestError(Exception):
  # Submitted a bad request, probably a 400 error
  pass

class TournamentError(Exception):
  # If tournament doesn't exist
  pass

class EventError(Exception):
  # Event doesn't exist
  pass

class PlayerError(Exception):
  # Player doesn't exist
  pass

class ResponseError(Exception):
  # Unknown other error
  pass


from pysmashgg import exceptions

def player_id_filter(response, player_name):
  # Error case
  if response['data']['event']['entrants']['nodes'] == None:
    return "Not Found"

  player_id = None

  for node in response['data']['event']['entrants']['nodes']:
    if node['participants'][0]['gamerTag'].lower() == player_name.lower():
      player_id = node['participants'][0]['player']['id']
    elif (node['participants'][0]['gamerTag'].split("|")[-1]).lower() == player_name.lower():
      player_id = node['participants'][0]['player']['id']

  return player_id

def show_with_brackets_filter(response, event_name):
  temp_id = None
  for event in response['data']['tournament']['events']:
    if event['slug'].split("/")[-1] == event_name:
      temp_id = event['id']
      event_name_new = event['name']
      bracket_url = event['slug']

      break
  
  if temp_id == None:
    print ("Event doesn't exist")
    raise exceptions.EventError

  del response['data']['tournament']['events']
  response['data']['tournament']['eventName'] = event_name_new
  response['data']['tournament']['bracketId'] = temp_id
  response['data']['tournament']['bracketUrl'] = bracket_url

  return response

def show_events_filter(response):
  event_list = []
  for event in response['data']['tournament']['events']:
    event_list.append(event['slug'].split("/")[-1])

  return {"events": event_list}

def event_id_filter(response, event_name):
  temp_id = None
  for event in response['data']['tournament']['events']:
    if event['slug'].split("/")[-1] == event_name:
      return event['id']

  if temp_id == None:
    print ("Event doesn't exist")
    raise exceptions.EventError

  return

# Filter for the show_sets function in tournaments.py
def show_sets_filter(response):
  if response['data']['event']['sets']['nodes'] == None:
    return
  
  sets = [] # Need for return at the end

  for node in response['data']['event']['sets']['nodes']:
    cur_set = {}
    cur_set['id'] = node['id']
    cur_set['entrant1Id'] = node['slots'][0]['entrant']['id']
    cur_set['entrant2Id'] = node['slots'][1]['entrant']['id']
    cur_set['entrant1Name'] = node['slots'][0]['entrant']['name']
    cur_set['entrant2Name'] = node['slots'][1]['entrant']['name']
    
    # Next 2 if/else blocks make sure there's a result in, sometimes DQs are weird
    if node['slots'][0]['standing']['stats']['score']['value'] != None:
      cur_set['entrant1Score'] = node['slots'][0]['standing']['stats']['score']['value']
    else:
      cur_set['entrant1Score'] = -1
    
    if node['slots'][1]['standing']['stats']['score']['value'] != None:
      cur_set['entrant2Score'] = node['slots'][1]['standing']['stats']['score']['value']
    else:
      cur_set['entrant2Score'] = -1

    # Determining winner/loser (elif because sometimes smashgg won't give us one)
    if node['slots'][0]['standing']['placement'] == 1:
      cur_set['winnerId'] = cur_set['entrant1Id']
      cur_set['loserId'] = cur_set['entrant2Id']
      cur_set['winnerName'] = cur_set['entrant1Name']
      cur_set['loserName'] = cur_set['entrant2Name']
    elif node['slots'][0]['standing']['placement'] == 2:
      cur_set['winnerId'] = cur_set['entrant2Id']
      cur_set['loserId'] = cur_set['entrant1Id']
      cur_set['winnerName'] = cur_set['entrant2Name']
      cur_set['loserName'] = cur_set['entrant1Name']

    cur_set['bracketName'] = node['phaseGroup']['phase']['name']
    cur_set['bracketId'] = node['phaseGroup']['id']

    sets.append(cur_set) # Adding that specific set onto the large list of sets

  return sets

def show_players_filter(response):
  if response['data']['event']['standings']['nodes'] == None:
    return
  
  players = []  # Need for return at the end
  
  for node in response['data']['event']['standings']['nodes']:
    cur_player = {}
    cur_player['entrantId'] = node['entrant']['id']
    cur_player['tag'] = node['entrant']['name']

    i = 1 # Yes, this is actually needed
    for user in node['entrant']['participants']: # This loop is used for when there is a team event
      player_id = "player" + str(i) + "Id"
      cur_player[player_id] = user['user']['player']['id']

      player_name = "player" + str(i) + "Name"
      if user['user']['name'] != None:
        cur_player[player_name] = user['user']['name']
      else:
        cur_player[player_name] = "Not listed"

      player_state = "player" + str(i) + "State"
      if user['user']['location']['state'] != None:
        cur_player[player_state] = user['user']['location']['state']
      else:
        cur_player[player_state] = "Not listed"

      player_country = "player" + str(i) + "Country"
      if user['user']['location']['country'] != None:
        cur_player[player_country] = user['user']['location']['country']
      else:
        cur_player[player_country] = "Not listed"

      i += 1

    cur_player['finalPlacement'] = node['placement']
    cur_player['seed'] = node['entrant']['seeds'][0]['seedNum']

    players.append(cur_player)

  return players

def show_events_brackets_filter(response, event_name):
  brackets = {}

  for event in response['data']['tournament']['events']:
    if event['slug'].split('/')[-1] == event_name:
      bracket_ids = []
      for node in event['phaseGroups']:
        bracket_ids.append(node['id'])

      brackets['bracketIds'] = bracket_ids
      brackets['eventName'] = event['name']
      brackets['slug'] = event['slug']

  return brackets

def show_player_sets_filter(response, player_id):
  if response['data']['event']['sets']['nodes'] == None:
    return
  
  sets = [] # Need for return at the end

  for node in response['data']['event']['sets']['nodes']:
    cur_set = {}
    cur_set['id'] = node['id']
    cur_set['entrant1Id'] = node['slots'][0]['entrant']['id']
    cur_set['entrant1Name'] = node['slots'][0]['entrant']['name']
    cur_set['player1Id'] = node['slots'][0]['entrant']['participants'][0]['user']['player']['id']
    cur_set['entrant2Id'] = node['slots'][1]['entrant']['id']
    cur_set['entrant2Name'] = node['slots'][1]['entrant']['name']
    cur_set['player2Id'] = node['slots'][1]['entrant']['participants'][0]['user']['player']['id']
    
    # Next 2 if/else blocks make sure there's a result in, sometimes DQs are weird
    if node['slots'][0]['standing']['stats']['score']['value'] != None:
      cur_set['entrant1Score'] = node['slots'][0]['standing']['stats']['score']['value']
    else:
      cur_set['entrant1Score'] = -1
    
    if node['slots'][1]['standing']['stats']['score']['value'] != None:
      cur_set['entrant2Score'] = node['slots'][1]['standing']['stats']['score']['value']
    else:
      cur_set['entrant2Score'] = -1

    # Determining winner/loser (elif because sometimes smashgg won't give us one)
    if node['slots'][0]['standing']['placement'] == 1:
      cur_set['winnerId'] = cur_set['entrant1Id']
      cur_set['loserId'] = cur_set['entrant2Id']
    elif node['slots'][0]['standing']['placement'] == 2:
      cur_set['winnerId'] = cur_set['entrant2Id']
      cur_set['loserId'] = cur_set['entrant1Id']

    cur_set['setRound'] = node['fullRoundText']
    cur_set['bracketId'] = node['phaseGroup']['id']

    sets.append(cur_set) # Adding that specific set onto the large list of sets

  return sets

def show_head_to_head_filter(response, player2_name):
  if response['data']['event']['sets']['nodes'] == None:
    return

  sets = []

  for node in response['data']['event']['sets']['nodes']:
    cur_set = {}
    # Yes, the if statement needs to be this long to account for all cases
    # I don't want to run another query, smash.gg's API can be trash sometimes
    if ((node['slots'][0]['entrant']['name'].split('|')[-1]).lower() == player2_name.lower()
      or node['slots'][0]['entrant']['name'].lower() == player2_name.lower()
      or (node['slots'][1]['entrant']['name'].split('|')[-1]).lower() == player2_name.lower()
      or node['slots'][1]['entrant']['name'].lower() == player2_name.lower()):
      cur_set = {}
      cur_set['id'] = node['id']
      cur_set['entrant1Id'] = node['slots'][0]['entrant']['id']
      cur_set['entrant1Name'] = node['slots'][0]['entrant']['name']
      cur_set['player1Id'] = node['slots'][0]['entrant']['participants'][0]['user']['player']['id']
      cur_set['entrant2Id'] = node['slots'][1]['entrant']['id']
      cur_set['entrant2Name'] = node['slots'][1]['entrant']['name']
      cur_set['player2Id'] = node['slots'][1]['entrant']['participants'][0]['user']['player']['id']
      
      # Next 2 if/else blocks make sure there's a result in, sometimes DQs are weird
      if node['slots'][0]['standing']['stats']['score']['value'] != None:
        cur_set['entrant1Score'] = node['slots'][0]['standing']['stats']['score']['value']
      else:
        cur_set['entrant1Score'] = -1
      
      if node['slots'][1]['standing']['stats']['score']['value'] != None:
        cur_set['entrant2Score'] = node['slots'][1]['standing']['stats']['score']['value']
      else:
        cur_set['entrant2Score'] = -1

      # Determining winner/loser (elif because sometimes smashgg won't give us one)
      if node['slots'][0]['standing']['placement'] == 1:
        cur_set['winnerId'] = cur_set['entrant1Id']
        cur_set['loserId'] = cur_set['entrant2Id']
      elif node['slots'][0]['standing']['placement'] == 2:
        cur_set['winnerId'] = cur_set['entrant2Id']
        cur_set['loserId'] = cur_set['entrant1Id']

      cur_set['setRound'] = node['fullRoundText']
      cur_set['bracketId'] = node['phaseGroup']['id']

      sets.append(cur_set)  # Adding that specific set onto the large list of sets
  
  return sets

def bracket_show_players_filter(response):
  if response['data']['phaseGroup']['seeds']['nodes'] == None:
    return
  
  players = []  # Need for return at the end

  for node in response['data']['phaseGroup']['seeds']['nodes']:
    cur_player = {}
    cur_player['entrantId'] = node['entrant']['id']
    cur_player['tag'] = node['entrant']['name']

    i = 1
    for player in node['players']: # This loop is used for when there is a team event
      player_id = "player" + str(i) + "Id"
      cur_player[player_id] = player['id']

      player_name = "player" + str(i) + "Name"
      if player['user']['name'] != None:
        cur_player[player_name] = player['user']['name']
      else:
        cur_player[player_name] = "Not listed"

      player_state = "player" + str(i) + "State"
      if player['user']['location']['state'] != None:
        cur_player[player_state] = player['user']['location']['state']
      else:
        cur_player[player_state] = "Not listed"

      player_country = "player" + str(i) + "Country"
      if player['user']['location']['country'] != None:
        cur_player[player_country] = player['user']['location']['country']
      else:
        cur_player[player_country] = "Not listed"

      i += 1

    cur_player['finalPlacement'] = node['placement']
    cur_player['seed'] = node['seedNum']

    players.append(cur_player)

  return players

def bracket_show_sets_filter(response):
  if response['data']['phaseGroup']['sets']['nodes'] == None:
    return
  bracket_name = response['data']['phaseGroup']['phase']['name']
  sets = [] # Need for return at the end

  for node in response['data']['phaseGroup']['sets']['nodes']:
    cur_set = {}
    cur_set['id'] = node['id']
    cur_set['entrant1Id'] = node['slots'][0]['entrant']['id']
    cur_set['entrant2Id'] = node['slots'][1]['entrant']['id']
    cur_set['entrant1Name'] = node['slots'][0]['entrant']['name']
    cur_set['entrant2Name'] = node['slots'][1]['entrant']['name']
    
    # Next 2 if/else blocks make sure there's a result in, sometimes DQs are weird
    if node['slots'][0]['standing']['stats']['score']['value'] != None:
      cur_set['entrant1Score'] = node['slots'][0]['standing']['stats']['score']['value']
    else:
      cur_set['entrant1Score'] = -1
    
    if node['slots'][1]['standing']['stats']['score']['value'] != None:
      cur_set['entrant2Score'] = node['slots'][1]['standing']['stats']['score']['value']
    else:
      cur_set['entrant2Score'] = -1

    # Determining winner/loser (elif because sometimes smashgg won't give us one)
    if node['slots'][0]['standing']['placement'] == 1:
      cur_set['winnerId'] = cur_set['entrant1Id']
      cur_set['loserId'] = cur_set['entrant2Id']
      cur_set['winnerName'] = cur_set['entrant1Name']
      cur_set['loserName'] = cur_set['entrant2Name']
    elif node['slots'][0]['standing']['placement'] == 2:
      cur_set['winnerId'] = cur_set['entrant2Id']
      cur_set['loserId'] = cur_set['entrant1Id']
      cur_set['winnerName'] = cur_set['entrant2Name']
      cur_set['loserName'] = cur_set['entrant1Name']

    cur_set['bracketName'] = bracket_name

    sets.append(cur_set) # Adding that specific set onto the large list of sets

  return sets


import requests
import json
from time import sleep
from pysmashgg import filters, queries
from pysmashgg.exceptions import TooManyRequestsError, BadRequestError, ResponseError, TournamentError, PlayerError

url = "https://api.smash.gg/gql/alpha"

def run_query(query, variables, header):  # Returns the response or the error code
  json_request = {'query': query, 'variables': variables}
  try:
    request = requests.post(url=url, json=json_request, headers=header)
    if request.status_code == 429:
      raise TooManyRequestsError
    elif request.status_code > 299 or request.status_code < 200:
      raise ResponseError

    response = json.loads(request.text)
    if 'errors' in response:
      raise BadRequestError
    if 'tournament' in response['data']:
      if response['data']['tournament'] == None:
        raise TournamentError

    return response

  except TooManyRequestsError:
    print("Sending too many requests right now, try again in like 30 seconds -- this will usually fix the error")
  except ResponseError:
    print("Unknown error, error code: " + str(request.status_code))
  except BadRequestError:
    print("Bad request, try again")
  except TournamentError:
    print("Tournament doesn't exist, try again")

  return

def get_player_id(event_id, player_name, header):
  query = queries.player_id_query()
  for i in range(1, 1000):  # Arbitrary number
    if i % 8 == 0:
      sleep(15) # This is necessary to avoid timing out the API
    variables = {"eventId": event_id, "page": i}
    player_id = filters.player_id_filter(run_query(query, variables, header), player_name)
    if player_id == 'Not Found':  # If no pages are left
      print("Player did not attend this event, try again")
      raise PlayerError
    elif type(player_id) == int:
      break
  
  return player_id

def get_event_id(tournament_name, event_name, header):
  query = queries.event_id_query()
  variables = {"tourneySlug": tournament_name}
  return filters.event_id_filter(run_query(query, variables, header), event_name)

def show(tournament_name, header):
  query = queries.metadata_query()
  variables = {"tourneySlug": tournament_name}
  response = run_query(query, variables, header)
  return response['data']['tournament']

def show_with_brackets(tournament_name, event_name, header):
  query = queries.metadata_with_brackets_query()
  variables = {"tourneySlug": tournament_name}
  response = filters.show_with_brackets_filter(run_query(query, variables, header), event_name)
  return response['data']['tournament']

# Showing 
def show_events(tournament_name, header):
  query = queries.events_query()
  variables = {"tourneySlug": tournament_name}
  response = filters.show_events_filter(run_query(query, variables, header))
  return response

# Showing all the sets from an event -- Don't mess with sleep_time unless you need to
# it acts as an automatic delay so you don't timeout the API
def show_sets(tournament_name, event_name, header, sleep_time):
  query = queries.show_sets_query()
  event_id = get_event_id(tournament_name, event_name, header)
  sets = []
  for i in range(1, 1000):  # Arbitrary number
    if i % 8 == 0:
      sleep(sleep_time) # This is necessary to avoid timing out the API
    variables = {"eventId": event_id, "page": i}
    response = filters.show_sets_filter(run_query(query, variables, header))
    if response == None: # If no pages are left
      break
    else: # If there is more data
      sets = sets + response

  return sets
      
# Shows all players from a specific event -- Don't mess with sleep_time unless you need to
# it acts as an automatic delay so you don't timeout the API
def show_players(tournament_name, event_name, header, sleep_time):
  query = queries.show_players_query()
  event_id = get_event_id(tournament_name, event_name, header)
  players = []
  for i in range(1, 1000):  # Arbitrary number
    if i % 8 == 0:
      sleep(sleep_time) # This is necessary to avoid timing out the API
    variables = {"eventId": event_id, "page": i}
    response = filters.show_players_filter(run_query(query, variables, header))
    if response == None: # If no pages are left
      break
    else: # If there is more data
      players = players + response

  return players

# Shows all the event bracket IDs as well as the name and slug of the event
def show_events_brackets(tournament_name, event_name, header):
  query = queries.show_events_brackets_query()
  variables = {"tourneySlug": tournament_name}
  return filters.show_events_brackets_filter(run_query(query, variables, header), event_name)

def show_player_sets(tournament_name, event_name, player_name, header):
  event_id = get_event_id(tournament_name, event_name, header)
  player_id = get_player_id(event_id, player_name, header)
  query = queries.show_player_sets_query()
  variables = {"eventId": event_id, "playerId": player_id, "page": 1}
  response = filters.show_player_sets_filter(run_query(query, variables, header), player_id)
  return response

def show_head_to_head(tournament_name, event_name, player1_name, player2_name, header):
  event_id = get_event_id(tournament_name, event_name, header)
  player_id = get_player_id(event_id, player1_name, header)
  query = queries.show_head_to_head_query()
  variables = variables = {"eventId": event_id, "playerId": player_id, "page": 1}
  response = filters.show_head_to_head_filter(run_query(query, variables, header), player2_name)
  return response

def bracket_show_players(bracket_id, sleep_time, header):
  query = queries.bracket_show_players_query()
  players = []

  for i in range(1, 1000):  # Arbitrary number
    if i % 8 == 0:
      sleep(sleep_time) # This is necessary to avoid timing out the API
    variables = {"phaseGroupId": bracket_id, "page": i}
    response = filters.bracket_show_players_filter(run_query(query, variables, header))
    if response == None: # If no pages are left
      break
    else: # If there is more data
      players = players + response

  return players

def bracket_show_sets(bracket_id, sleep_time, header):
  query = queries.bracket_show_sets_query()
  sets = []
  for i in range(1, 1000):  # Arbitrary number
    if i % 8 == 0:
      sleep(sleep_time) # This is necessary to avoid timing out the API
    variables = {"phaseGroupId": bracket_id, "page": i}
    response = filters.bracket_show_sets_filter(run_query(query, variables, header))
    if response == None: # If no pages are left
      break
    else: # If there is more data
      sets = sets + response

  return sets